# List of assets to add

## Confirmed

- Web API: Declare an auto-discoverable API, like GraphQL with Schema introspection, SOAP or REST with OpenAPI
- Container
- Git Repo
- AWS Cloud Project
- Azure Cloud Project
- GCP Cloud Project

## Potential

- Kubernetes Cluster
- Database
- SaaS Services